yakumo.neutron.v2.lb.member.Manager

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module member :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for LB backend members in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for LB backend members in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.lb.member.Resource |
create(self, address=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`, weight=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a LB member for a pool | source code
_find_gen(self, **kwargs) | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.Manager`: `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``member``'``
| _json_resources_key = ``'``members``'``
| _url_resource_path = ``'``/v2.0/lb/members``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, address=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`, weight=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a LB member for a pool Parameters: `address` (str) - IP address (required) `port` (str) - Port (required) `weight` (int) - Member weight `is_enabled` (bool) - Whether the member is enabled Returns: yakumo.neutron.v2.lb.member.Resource Created member Overrides: base.Manager.create

### _find_gen(self, **kwargs) | source code
Overrides: base.Manager._find_gen

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('
      project')), ('pool', 'pool_id', mapper.Resource('neutron.lb.pool')), (
      'is_enabled', 'admin_state_up', mapper.Noop), ('protocol_port', 'proto
      col_port', mapper.Noop), ('weight', 'weight', mapper.Noop), ('status',
       'status', mapper.Noop), ('address', 'address', mapper.Noop),]